Processing
----------

.. automodule:: pyroSAR.gamma.util
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        calibrate
        convert2gamma
        correctOSV
        gc_map_wrap
        geocode
        lat_linear_to_db
        lat_product
        lat_ratio
        multilook
        ovs
        pixel_area_wrap
        S1_deburst